# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKLabelMapPython



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkShapeLabelObjectPython
else:
    import _itkShapeLabelObjectPython

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkLabelObjectPython
import itk.itkOffsetPython
import itk.itkSizePython
import itk.pyBasePython
import itk.itkLabelObjectLinePython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.vnl_matrixPython
import itk.stdcomplexPython
import itk.vnl_vectorPython
import itk.vnl_matrix_fixedPython
import itk.itkCovariantVectorPython
import itk.itkFixedArrayPython
import itk.vnl_vector_refPython
import itk.itkVectorPython
import itk.itkPointPython
import itk.itkIndexPython
import itk.itkImageRegionPython
import itk.itkAffineTransformPython
import itk.itkTransformBasePython
import itk.itkDiffusionTensor3DPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkOptimizerParametersPython
import itk.itkArrayPython
import itk.itkArray2DPython
import itk.itkVariableLengthVectorPython
import itk.itkMatrixOffsetTransformBasePython
class itkFixedArrayPD24(object):
    r"""Proxy of C++ itkFixedArrayPD24 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __eq__(self, r):
        r"""
        __eq__(self, r) -> bool

        Parameters
        ----------
        r: itkFixedArrayPD24 const &

        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD24___eq__(self, r)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkFixedArrayPD24 const &

        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD24___ne__(self, other)

    def SetElement(self, index, value):
        r"""
        SetElement(self, index, value)

        Parameters
        ----------
        index: unsigned int
        value: itkPointD2 const &

        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD24_SetElement(self, index, value)

    def GetElement(self, index):
        r"""
        GetElement(self, index) -> itkPointD2

        Parameters
        ----------
        index: unsigned int

        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD24_GetElement(self, index)

    def GetDataPointer(self, *args):
        r"""
        GetDataPointer(self) -> itkPointD2
        GetDataPointer(self) -> itkPointD2
        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD24_GetDataPointer(self, *args)

    def data(self, *args):
        r"""
        data(self) -> itkPointD2
        data(self) -> itkPointD2
        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD24_data(self, *args)

    def cbegin(self):
        r"""cbegin(self) -> itkPointD2"""
        return _itkShapeLabelObjectPython.itkFixedArrayPD24_cbegin(self)

    def begin(self, *args):
        r"""
        begin(self) -> itkPointD2
        begin(self) -> itkPointD2
        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD24_begin(self, *args)

    def cend(self):
        r"""cend(self) -> itkPointD2"""
        return _itkShapeLabelObjectPython.itkFixedArrayPD24_cend(self)

    def end(self, *args):
        r"""
        end(self) -> itkPointD2
        end(self) -> itkPointD2
        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD24_end(self, *args)

    def crbegin(self):
        r"""crbegin(self) -> std::reverse_iterator< itk::Point< double,2 > const * >"""
        return _itkShapeLabelObjectPython.itkFixedArrayPD24_crbegin(self)

    def rbegin(self, *args):
        r"""
        rbegin(self) -> std::reverse_iterator< itkPointD2 * >
        rbegin(self) -> std::reverse_iterator< itk::Point< double,2 > const * >
        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD24_rbegin(self, *args)

    def crend(self):
        r"""crend(self) -> std::reverse_iterator< itk::Point< double,2 > const * >"""
        return _itkShapeLabelObjectPython.itkFixedArrayPD24_crend(self)

    def rend(self, *args):
        r"""
        rend(self) -> std::reverse_iterator< itkPointD2 * >
        rend(self) -> std::reverse_iterator< itk::Point< double,2 > const * >
        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD24_rend(self, *args)

    def Size(self):
        r"""Size(self) -> unsigned int"""
        return _itkShapeLabelObjectPython.itkFixedArrayPD24_Size(self)

    def size(self):
        r"""size(self) -> unsigned int"""
        return _itkShapeLabelObjectPython.itkFixedArrayPD24_size(self)

    def Fill(self, arg0):
        r"""
        Fill(self, arg0)

        Parameters
        ----------
        arg0: itkPointD2 const &

        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD24_Fill(self, arg0)

    def swap(self, other):
        r"""
        swap(self, other)

        Parameters
        ----------
        other: itkFixedArrayPD24 &

        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD24_swap(self, other)

    @staticmethod
    def Filled(value):
        r"""
        Filled(value) -> itkFixedArrayPD24

        Parameters
        ----------
        value: itkPointD2 const &

        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD24_Filled(value)

    def __init__(self, *args):
        r"""
        __init__(self) -> itkFixedArrayPD24
        __init__(self, r) -> itkFixedArrayPD24

        Parameters
        ----------
        r: itkPointD2 const *

        __init__(self, arg0) -> itkFixedArrayPD24

        Parameters
        ----------
        arg0: itkPointD2 const &

        __init__(self, stdArray) -> itkFixedArrayPD24

        Parameters
        ----------
        stdArray: std::array< itkPointD2,4 > const &

        __init__(self, arg0) -> itkFixedArrayPD24

        Parameters
        ----------
        arg0: itkFixedArrayPD24 const &

        """
        _itkShapeLabelObjectPython.itkFixedArrayPD24_swiginit(self, _itkShapeLabelObjectPython.new_itkFixedArrayPD24(*args))
    __swig_destroy__ = _itkShapeLabelObjectPython.delete_itkFixedArrayPD24

# Register itkFixedArrayPD24 in _itkShapeLabelObjectPython:
_itkShapeLabelObjectPython.itkFixedArrayPD24_swigregister(itkFixedArrayPD24)
class itkFixedArrayPD38(object):
    r"""Proxy of C++ itkFixedArrayPD38 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def __eq__(self, r):
        r"""
        __eq__(self, r) -> bool

        Parameters
        ----------
        r: itkFixedArrayPD38 const &

        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD38___eq__(self, r)

    def __ne__(self, other):
        r"""
        __ne__(self, other) -> bool

        Parameters
        ----------
        other: itkFixedArrayPD38 const &

        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD38___ne__(self, other)

    def SetElement(self, index, value):
        r"""
        SetElement(self, index, value)

        Parameters
        ----------
        index: unsigned int
        value: itkPointD3 const &

        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD38_SetElement(self, index, value)

    def GetElement(self, index):
        r"""
        GetElement(self, index) -> itkPointD3

        Parameters
        ----------
        index: unsigned int

        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD38_GetElement(self, index)

    def GetDataPointer(self, *args):
        r"""
        GetDataPointer(self) -> itkPointD3
        GetDataPointer(self) -> itkPointD3
        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD38_GetDataPointer(self, *args)

    def data(self, *args):
        r"""
        data(self) -> itkPointD3
        data(self) -> itkPointD3
        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD38_data(self, *args)

    def cbegin(self):
        r"""cbegin(self) -> itkPointD3"""
        return _itkShapeLabelObjectPython.itkFixedArrayPD38_cbegin(self)

    def begin(self, *args):
        r"""
        begin(self) -> itkPointD3
        begin(self) -> itkPointD3
        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD38_begin(self, *args)

    def cend(self):
        r"""cend(self) -> itkPointD3"""
        return _itkShapeLabelObjectPython.itkFixedArrayPD38_cend(self)

    def end(self, *args):
        r"""
        end(self) -> itkPointD3
        end(self) -> itkPointD3
        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD38_end(self, *args)

    def crbegin(self):
        r"""crbegin(self) -> std::reverse_iterator< itk::Point< double > const * >"""
        return _itkShapeLabelObjectPython.itkFixedArrayPD38_crbegin(self)

    def rbegin(self, *args):
        r"""
        rbegin(self) -> std::reverse_iterator< itkPointD3 * >
        rbegin(self) -> std::reverse_iterator< itk::Point< double > const * >
        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD38_rbegin(self, *args)

    def crend(self):
        r"""crend(self) -> std::reverse_iterator< itk::Point< double > const * >"""
        return _itkShapeLabelObjectPython.itkFixedArrayPD38_crend(self)

    def rend(self, *args):
        r"""
        rend(self) -> std::reverse_iterator< itkPointD3 * >
        rend(self) -> std::reverse_iterator< itk::Point< double > const * >
        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD38_rend(self, *args)

    def Size(self):
        r"""Size(self) -> unsigned int"""
        return _itkShapeLabelObjectPython.itkFixedArrayPD38_Size(self)

    def size(self):
        r"""size(self) -> unsigned int"""
        return _itkShapeLabelObjectPython.itkFixedArrayPD38_size(self)

    def Fill(self, arg0):
        r"""
        Fill(self, arg0)

        Parameters
        ----------
        arg0: itkPointD3 const &

        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD38_Fill(self, arg0)

    def swap(self, other):
        r"""
        swap(self, other)

        Parameters
        ----------
        other: itkFixedArrayPD38 &

        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD38_swap(self, other)

    @staticmethod
    def Filled(value):
        r"""
        Filled(value) -> itkFixedArrayPD38

        Parameters
        ----------
        value: itkPointD3 const &

        """
        return _itkShapeLabelObjectPython.itkFixedArrayPD38_Filled(value)

    def __init__(self, *args):
        r"""
        __init__(self) -> itkFixedArrayPD38
        __init__(self, r) -> itkFixedArrayPD38

        Parameters
        ----------
        r: itkPointD3 const *

        __init__(self, arg0) -> itkFixedArrayPD38

        Parameters
        ----------
        arg0: itkPointD3 const &

        __init__(self, stdArray) -> itkFixedArrayPD38

        Parameters
        ----------
        stdArray: std::array< itkPointD3,8 > const &

        __init__(self, arg0) -> itkFixedArrayPD38

        Parameters
        ----------
        arg0: itkFixedArrayPD38 const &

        """
        _itkShapeLabelObjectPython.itkFixedArrayPD38_swiginit(self, _itkShapeLabelObjectPython.new_itkFixedArrayPD38(*args))
    __swig_destroy__ = _itkShapeLabelObjectPython.delete_itkFixedArrayPD38

# Register itkFixedArrayPD38 in _itkShapeLabelObjectPython:
_itkShapeLabelObjectPython.itkFixedArrayPD38_swigregister(itkFixedArrayPD38)

def itkShapeLabelObjectUL2_New():
    return itkShapeLabelObjectUL2.New()

class itkShapeLabelObjectUL2(itk.itkLabelObjectPython.itkLabelObjectUL2):
    r"""Proxy of C++ itkShapeLabelObjectUL2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShapeLabelObjectUL2_Pointer"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShapeLabelObjectUL2_Pointer"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_Clone(self)

    @staticmethod
    def GetAttributeFromName(s):
        r"""
        GetAttributeFromName(s) -> unsigned int

        Parameters
        ----------
        s: std::string const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetAttributeFromName(s)

    @staticmethod
    def GetNameFromAttribute(a):
        r"""
        GetNameFromAttribute(a) -> std::string

        Parameters
        ----------
        a: unsigned int const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetNameFromAttribute(a)

    def GetBoundingBox(self):
        r"""GetBoundingBox(self) -> itkImageRegion2"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetBoundingBox(self)

    def SetBoundingBox(self, v):
        r"""
        SetBoundingBox(self, v)

        Parameters
        ----------
        v: itkImageRegion2 const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetBoundingBox(self, v)

    def GetPhysicalSize(self):
        r"""GetPhysicalSize(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetPhysicalSize(self)

    def SetPhysicalSize(self, v):
        r"""
        SetPhysicalSize(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetPhysicalSize(self, v)

    def GetNumberOfPixels(self):
        r"""GetNumberOfPixels(self) -> unsigned long const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetNumberOfPixels(self)

    def SetNumberOfPixels(self, v):
        r"""
        SetNumberOfPixels(self, v)

        Parameters
        ----------
        v: unsigned long const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetNumberOfPixels(self, v)

    def GetCentroid(self):
        r"""GetCentroid(self) -> itkPointD2"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetCentroid(self)

    def SetCentroid(self, centroid):
        r"""
        SetCentroid(self, centroid)

        Parameters
        ----------
        centroid: itkPointD2 const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetCentroid(self, centroid)

    def GetNumberOfPixelsOnBorder(self):
        r"""GetNumberOfPixelsOnBorder(self) -> unsigned long const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetNumberOfPixelsOnBorder(self)

    def SetNumberOfPixelsOnBorder(self, v):
        r"""
        SetNumberOfPixelsOnBorder(self, v)

        Parameters
        ----------
        v: unsigned long const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetNumberOfPixelsOnBorder(self, v)

    def GetPerimeterOnBorder(self):
        r"""GetPerimeterOnBorder(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetPerimeterOnBorder(self)

    def SetPerimeterOnBorder(self, v):
        r"""
        SetPerimeterOnBorder(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetPerimeterOnBorder(self, v)

    def GetFeretDiameter(self):
        r"""GetFeretDiameter(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetFeretDiameter(self)

    def SetFeretDiameter(self, v):
        r"""
        SetFeretDiameter(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetFeretDiameter(self, v)

    def GetPrincipalMoments(self):
        r"""GetPrincipalMoments(self) -> itkVectorD2"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetPrincipalMoments(self)

    def SetPrincipalMoments(self, v):
        r"""
        SetPrincipalMoments(self, v)

        Parameters
        ----------
        v: itkVectorD2 const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetPrincipalMoments(self, v)

    def GetPrincipalAxes(self):
        r"""GetPrincipalAxes(self) -> itkMatrixD22"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetPrincipalAxes(self)

    def SetPrincipalAxes(self, v):
        r"""
        SetPrincipalAxes(self, v)

        Parameters
        ----------
        v: itkMatrixD22 const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetPrincipalAxes(self, v)

    def GetElongation(self):
        r"""GetElongation(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetElongation(self)

    def SetElongation(self, v):
        r"""
        SetElongation(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetElongation(self, v)

    def GetPerimeter(self):
        r"""GetPerimeter(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetPerimeter(self)

    def SetPerimeter(self, v):
        r"""
        SetPerimeter(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetPerimeter(self, v)

    def GetRoundness(self):
        r"""GetRoundness(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetRoundness(self)

    def SetRoundness(self, v):
        r"""
        SetRoundness(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetRoundness(self, v)

    def GetEquivalentSphericalRadius(self):
        r"""GetEquivalentSphericalRadius(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetEquivalentSphericalRadius(self)

    def SetEquivalentSphericalRadius(self, v):
        r"""
        SetEquivalentSphericalRadius(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetEquivalentSphericalRadius(self, v)

    def GetEquivalentSphericalPerimeter(self):
        r"""GetEquivalentSphericalPerimeter(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetEquivalentSphericalPerimeter(self)

    def SetEquivalentSphericalPerimeter(self, v):
        r"""
        SetEquivalentSphericalPerimeter(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetEquivalentSphericalPerimeter(self, v)

    def GetEquivalentEllipsoidDiameter(self):
        r"""GetEquivalentEllipsoidDiameter(self) -> itkVectorD2"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetEquivalentEllipsoidDiameter(self)

    def SetEquivalentEllipsoidDiameter(self, v):
        r"""
        SetEquivalentEllipsoidDiameter(self, v)

        Parameters
        ----------
        v: itkVectorD2 const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetEquivalentEllipsoidDiameter(self, v)

    def GetFlatness(self):
        r"""GetFlatness(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetFlatness(self)

    def SetFlatness(self, v):
        r"""
        SetFlatness(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetFlatness(self, v)

    def GetPerimeterOnBorderRatio(self):
        r"""GetPerimeterOnBorderRatio(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetPerimeterOnBorderRatio(self)

    def SetPerimeterOnBorderRatio(self, v):
        r"""
        SetPerimeterOnBorderRatio(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetPerimeterOnBorderRatio(self, v)

    def GetOrientedBoundingBoxOrigin(self):
        r"""GetOrientedBoundingBoxOrigin(self) -> itkPointD2"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetOrientedBoundingBoxOrigin(self)

    def SetOrientedBoundingBoxOrigin(self, v):
        r"""
        SetOrientedBoundingBoxOrigin(self, v)

        Parameters
        ----------
        v: itkPointD2 const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetOrientedBoundingBoxOrigin(self, v)

    def GetOrientedBoundingBoxSize(self):
        r"""GetOrientedBoundingBoxSize(self) -> itkVectorD2"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetOrientedBoundingBoxSize(self)

    def SetOrientedBoundingBoxSize(self, v):
        r"""
        SetOrientedBoundingBoxSize(self, v)

        Parameters
        ----------
        v: itkVectorD2 const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_SetOrientedBoundingBoxSize(self, v)

    def GetRegion(self):
        r"""GetRegion(self) -> itkImageRegion2"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetRegion(self)

    def GetOrientedBoundingBoxDirection(self):
        r"""GetOrientedBoundingBoxDirection(self) -> itkMatrixD22"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetOrientedBoundingBoxDirection(self)

    def GetOrientedBoundingBoxVertices(self):
        r"""GetOrientedBoundingBoxVertices(self) -> itkFixedArrayPD24"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetOrientedBoundingBoxVertices(self)

    def GetPrincipalAxesToPhysicalAxesTransform(self):
        r"""GetPrincipalAxesToPhysicalAxesTransform(self) -> itkAffineTransformD2_Pointer"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetPrincipalAxesToPhysicalAxesTransform(self)

    def GetPhysicalAxesToPrincipalAxesTransform(self):
        r"""GetPhysicalAxesToPrincipalAxesTransform(self) -> itkAffineTransformD2_Pointer"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_GetPhysicalAxesToPrincipalAxesTransform(self)
    __swig_destroy__ = _itkShapeLabelObjectPython.delete_itkShapeLabelObjectUL2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShapeLabelObjectUL2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL2_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShapeLabelObjectUL2

        Create a new object of the class itkShapeLabelObjectUL2 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShapeLabelObjectUL2.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShapeLabelObjectUL2.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShapeLabelObjectUL2.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShapeLabelObjectUL2 in _itkShapeLabelObjectPython:
_itkShapeLabelObjectPython.itkShapeLabelObjectUL2_swigregister(itkShapeLabelObjectUL2)

def itkShapeLabelObjectUL3_New():
    return itkShapeLabelObjectUL3.New()

class itkShapeLabelObjectUL3(itk.itkLabelObjectPython.itkLabelObjectUL3):
    r"""Proxy of C++ itkShapeLabelObjectUL3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined")
    __repr__ = _swig_repr

    @staticmethod
    def __New_orig__():
        r"""__New_orig__() -> itkShapeLabelObjectUL3_Pointer"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3___New_orig__()

    def Clone(self):
        r"""Clone(self) -> itkShapeLabelObjectUL3_Pointer"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_Clone(self)

    @staticmethod
    def GetAttributeFromName(s):
        r"""
        GetAttributeFromName(s) -> unsigned int

        Parameters
        ----------
        s: std::string const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetAttributeFromName(s)

    @staticmethod
    def GetNameFromAttribute(a):
        r"""
        GetNameFromAttribute(a) -> std::string

        Parameters
        ----------
        a: unsigned int const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetNameFromAttribute(a)

    def GetBoundingBox(self):
        r"""GetBoundingBox(self) -> itkImageRegion3"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetBoundingBox(self)

    def SetBoundingBox(self, v):
        r"""
        SetBoundingBox(self, v)

        Parameters
        ----------
        v: itkImageRegion3 const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetBoundingBox(self, v)

    def GetPhysicalSize(self):
        r"""GetPhysicalSize(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetPhysicalSize(self)

    def SetPhysicalSize(self, v):
        r"""
        SetPhysicalSize(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetPhysicalSize(self, v)

    def GetNumberOfPixels(self):
        r"""GetNumberOfPixels(self) -> unsigned long const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetNumberOfPixels(self)

    def SetNumberOfPixels(self, v):
        r"""
        SetNumberOfPixels(self, v)

        Parameters
        ----------
        v: unsigned long const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetNumberOfPixels(self, v)

    def GetCentroid(self):
        r"""GetCentroid(self) -> itkPointD3"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetCentroid(self)

    def SetCentroid(self, centroid):
        r"""
        SetCentroid(self, centroid)

        Parameters
        ----------
        centroid: itkPointD3 const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetCentroid(self, centroid)

    def GetNumberOfPixelsOnBorder(self):
        r"""GetNumberOfPixelsOnBorder(self) -> unsigned long const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetNumberOfPixelsOnBorder(self)

    def SetNumberOfPixelsOnBorder(self, v):
        r"""
        SetNumberOfPixelsOnBorder(self, v)

        Parameters
        ----------
        v: unsigned long const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetNumberOfPixelsOnBorder(self, v)

    def GetPerimeterOnBorder(self):
        r"""GetPerimeterOnBorder(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetPerimeterOnBorder(self)

    def SetPerimeterOnBorder(self, v):
        r"""
        SetPerimeterOnBorder(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetPerimeterOnBorder(self, v)

    def GetFeretDiameter(self):
        r"""GetFeretDiameter(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetFeretDiameter(self)

    def SetFeretDiameter(self, v):
        r"""
        SetFeretDiameter(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetFeretDiameter(self, v)

    def GetPrincipalMoments(self):
        r"""GetPrincipalMoments(self) -> itkVectorD3"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetPrincipalMoments(self)

    def SetPrincipalMoments(self, v):
        r"""
        SetPrincipalMoments(self, v)

        Parameters
        ----------
        v: itkVectorD3 const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetPrincipalMoments(self, v)

    def GetPrincipalAxes(self):
        r"""GetPrincipalAxes(self) -> itkMatrixD33"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetPrincipalAxes(self)

    def SetPrincipalAxes(self, v):
        r"""
        SetPrincipalAxes(self, v)

        Parameters
        ----------
        v: itkMatrixD33 const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetPrincipalAxes(self, v)

    def GetElongation(self):
        r"""GetElongation(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetElongation(self)

    def SetElongation(self, v):
        r"""
        SetElongation(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetElongation(self, v)

    def GetPerimeter(self):
        r"""GetPerimeter(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetPerimeter(self)

    def SetPerimeter(self, v):
        r"""
        SetPerimeter(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetPerimeter(self, v)

    def GetRoundness(self):
        r"""GetRoundness(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetRoundness(self)

    def SetRoundness(self, v):
        r"""
        SetRoundness(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetRoundness(self, v)

    def GetEquivalentSphericalRadius(self):
        r"""GetEquivalentSphericalRadius(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetEquivalentSphericalRadius(self)

    def SetEquivalentSphericalRadius(self, v):
        r"""
        SetEquivalentSphericalRadius(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetEquivalentSphericalRadius(self, v)

    def GetEquivalentSphericalPerimeter(self):
        r"""GetEquivalentSphericalPerimeter(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetEquivalentSphericalPerimeter(self)

    def SetEquivalentSphericalPerimeter(self, v):
        r"""
        SetEquivalentSphericalPerimeter(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetEquivalentSphericalPerimeter(self, v)

    def GetEquivalentEllipsoidDiameter(self):
        r"""GetEquivalentEllipsoidDiameter(self) -> itkVectorD3"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetEquivalentEllipsoidDiameter(self)

    def SetEquivalentEllipsoidDiameter(self, v):
        r"""
        SetEquivalentEllipsoidDiameter(self, v)

        Parameters
        ----------
        v: itkVectorD3 const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetEquivalentEllipsoidDiameter(self, v)

    def GetFlatness(self):
        r"""GetFlatness(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetFlatness(self)

    def SetFlatness(self, v):
        r"""
        SetFlatness(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetFlatness(self, v)

    def GetPerimeterOnBorderRatio(self):
        r"""GetPerimeterOnBorderRatio(self) -> double const &"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetPerimeterOnBorderRatio(self)

    def SetPerimeterOnBorderRatio(self, v):
        r"""
        SetPerimeterOnBorderRatio(self, v)

        Parameters
        ----------
        v: double const

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetPerimeterOnBorderRatio(self, v)

    def GetOrientedBoundingBoxOrigin(self):
        r"""GetOrientedBoundingBoxOrigin(self) -> itkPointD3"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetOrientedBoundingBoxOrigin(self)

    def SetOrientedBoundingBoxOrigin(self, v):
        r"""
        SetOrientedBoundingBoxOrigin(self, v)

        Parameters
        ----------
        v: itkPointD3 const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetOrientedBoundingBoxOrigin(self, v)

    def GetOrientedBoundingBoxSize(self):
        r"""GetOrientedBoundingBoxSize(self) -> itkVectorD3"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetOrientedBoundingBoxSize(self)

    def SetOrientedBoundingBoxSize(self, v):
        r"""
        SetOrientedBoundingBoxSize(self, v)

        Parameters
        ----------
        v: itkVectorD3 const &

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_SetOrientedBoundingBoxSize(self, v)

    def GetRegion(self):
        r"""GetRegion(self) -> itkImageRegion3"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetRegion(self)

    def GetOrientedBoundingBoxDirection(self):
        r"""GetOrientedBoundingBoxDirection(self) -> itkMatrixD33"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetOrientedBoundingBoxDirection(self)

    def GetOrientedBoundingBoxVertices(self):
        r"""GetOrientedBoundingBoxVertices(self) -> itkFixedArrayPD38"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetOrientedBoundingBoxVertices(self)

    def GetPrincipalAxesToPhysicalAxesTransform(self):
        r"""GetPrincipalAxesToPhysicalAxesTransform(self) -> itkAffineTransformD3_Pointer"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetPrincipalAxesToPhysicalAxesTransform(self)

    def GetPhysicalAxesToPrincipalAxesTransform(self):
        r"""GetPhysicalAxesToPrincipalAxesTransform(self) -> itkAffineTransformD3_Pointer"""
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_GetPhysicalAxesToPrincipalAxesTransform(self)
    __swig_destroy__ = _itkShapeLabelObjectPython.delete_itkShapeLabelObjectUL3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkShapeLabelObjectUL3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkShapeLabelObjectPython.itkShapeLabelObjectUL3_cast(obj)

    def New(*args, **kargs):
        """New() -> itkShapeLabelObjectUL3

        Create a new object of the class itkShapeLabelObjectUL3 and set the input and the parameters if some
        named or non-named arguments are passed to that method.

        New() tries to assign all the non named parameters to the input of the new objects - the
        first non named parameter in the first input, etc.

        The named parameters are used by calling the method with the same name prefixed by 'Set'.

        Ex:

          itkShapeLabelObjectUL3.New(reader, threshold=10)

        is (most of the time) equivalent to:

          obj = itkShapeLabelObjectUL3.New()
          obj.SetInput(0, reader.GetOutput())
          obj.SetThreshold(10)
        """
        obj = itkShapeLabelObjectUL3.__New_orig__()
        from itk.support import template_class
        template_class.New(obj, *args, **kargs)
        return obj
    New = staticmethod(New)


# Register itkShapeLabelObjectUL3 in _itkShapeLabelObjectPython:
_itkShapeLabelObjectPython.itkShapeLabelObjectUL3_swigregister(itkShapeLabelObjectUL3)

